pub struct CredentialConfig {
pub tenant_id: Option<String>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub disable_managed_identity: bool,
}Expand description
Configuration for credential resolution.
Fields
tenant_id: Option<String>client_id: Option<String>client_secret: Option<String>disable_managed_identity: boolImplementations
Sourceimpl CredentialConfig
impl CredentialConfig
Sourcepub fn resolve_credential_type(&self) -> Result<CredentialType>
pub fn resolve_credential_type(&self) -> Result<CredentialType>
Determines which credential type should be used based on the configuration.
Sourcepub fn has_client_secret_credentials(&self) -> bool
pub fn has_client_secret_credentials(&self) -> bool
Checks if all client secret credentials are present.
Sourcepub fn has_partial_credentials(&self) -> bool
pub fn has_partial_credentials(&self) -> bool
Checks if any partial client secret credentials are present.